@@ -19,7 +19,7 @@ impl PulsedOp for AxisOp {
     fn pulsed_output_facts(&self, inputs: &[&PulsedFact]) -> TractResult<TVec<PulsedFact>> {
         let mut fact = inputs[0].clone();
         fact.shape = inputs[0].shape.clone();
-        self.change_shape_array(&mut fact.shape, false)?;
+        self.change_shape(&mut fact.shape, false)?;
         fact.axis = self
             .transform_axis(fact.axis)
             .ok_or_else(|| format_err!("Invalid axis for pulsification"))?;
